@@ -3,7 +3,7 @@ from emora_stdm import DialogueFlow
 
 
 system = DialogueFlow('start', initial_speaker=DialogueFlow.Speaker.USER)
-system.load_transitions({'state': 'start'})
+system.load_transitions({'state': 'start', 'error': {'` `': {'score': -1, 'state': 'start'}}})
 
 system.load_update_rules({
     '[news]': '`Coronavirus, argh!` (1)',
