@@ -142,19 +142,10 @@ def test_DIFFERENCE():
 
 def test_SET():
     vars = {'a': 'apple', 'b': 'banana'}
-    natex = NatexNLU('[!#SET($a=pie, $c=cookie, $d=dog), hello world]', macros=macros)
+    natex = NatexNLU('[!#SET($a=pie), hello world]', macros=macros)
     assert natex.match('hello world', vars=vars, debugging=False)
     assert vars['a'] == 'pie'
     assert vars['b'] == 'banana'
-    assert vars['c'] == 'cookie'
-    assert vars['d'] == 'dog'
-    assert len(vars) == 4
-    vars = {'a': 'apple', 'b': 'banana'}
-    natex = NatexNLU('[!#SET($a=pie, $c=cookie), hello $d=dog]', macros=macros)
-    assert natex.match('hello dog', vars=vars)
-    assert vars['d'] == 'dog'
-    assert vars['a'] == 'pie'
-    assert vars['c'] == 'cookie'
 
 def test_ALL():
     natex = NatexNLU('[!#ALL($a=apple, $b=banana), hello]', macros=macros)
@@ -278,7 +269,7 @@ def test_DISAGREE():
     assert not match
     match = natex.match('of course', debugging=False)
     assert not match
-    match = natex.match('i dont think so', debugging=False)
+    match = natex.match('i do not think so', debugging=False)
     assert match
     match = natex.match('i think so', debugging=False)
     assert not match
